declared-package: declared: Functions for Declared Missing Values

declared-packageR Documentation

declared: Functions for Declared Missing Values

Description

A zero dependency package containing functions to declare labels and missing values, coupled with associated functions to create (weighted) tables of frequencies and various other summary measures. Some of the base functions have been rewritten to make use of the specific information about the missing values, most importantly to distinguish between empty and declared NA values. Some functions have similar functionality with the corresponding ones from packages "haven" and "labelled". The aim is to ensure as much compatibility as possible with these packages, while offering an alternative in the objects of class "declared".

Author(s)

Maintainer: Adrian Dusa dusa.adrian@unibuc.ro (ORCID) [copyright holder]

Authors:

See Also

Useful links:


declared documentation built on Aug. 22, 2026, 9:07 a.m.